netapp_ontap.models.volume_constituents_space_logical_space API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_constituents_space_logical_space`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeConstituentsSpaceLogicalSpaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeConstituentsSpaceLogicalSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available: Size GET`

    The amount of space available in this volume with storage efficiency space considered used, in bytes.

  `enforcement: bool GET POST PATCH`

    Specifies whether space accounting for operations on the volume is done along with storage efficiency.

  `reporting: bool GET POST PATCH`

    Specifies whether space reporting on the volume is done along with storage efficiency.

  `used_by_afs: Size GET`

    The virtual space used by AFS alone (includes volume reserves) and along with storage efficiency, in bytes.